@@ -20,7 +20,7 @@ Contact: yuvraaj@gmail.com
 */
 
 #include "CacheDatabase.h"
-#include "GVAccess.h"
+#include "GVApi.h"
 #include "ContactsModel.h"
 #include "InboxModel.h"
 #include "Singletons.h"
@@ -530,8 +530,8 @@ CacheDatabase::putContactInfo (const ContactInfo &info)
     foreach (PhoneInfo entry, info.arrPhones)
     {
         QString strNum = entry.strNumber;
-        if (GVAccess::isNumberValid (strNum)) {
-            GVAccess::simplify_number (strNum);
+        if (GVApi::isNumberValid (strNum)) {
+            GVApi::simplify_number (strNum);
         }
         strNum = PhoneInfo::typeToChar(entry.Type) + strNum;
         strNum.replace ("'", "''");
@@ -621,7 +621,7 @@ CacheDatabase::getContactFromNumber (const QString &strNumber,
     scrubNumber.replace ("'", "''");
     strQ = QString ("SELECT " GV_L_LINK " FROM " GV_LINKS_TABLE " "
                     "WHERE " GV_L_TYPE "='" GV_L_TYPE_NUMBER "' "
-                    "AND " GV_L_DATA " LIKE '%%%1'")
+                    "AND " GV_L_DATA " LIKE '%%%1%%'")
                     .arg (scrubNumber);
     query.exec (strQ);
 
@@ -923,7 +923,7 @@ CacheDatabase::getTextsByDate(QDateTime dtStart, QDateTime dtEnd)
         }
 
         QString strNum = query.value(1).toString();
-        GVAccess::simplify_number (strNum, false);
+        GVApi::simplify_number (strNum, false);
         ContactInfo info;
         getContactFromNumber (strNum, info);
 
@@ -953,7 +953,7 @@ CacheDatabase::getTextsByContact(const QString &strContact)
     ContactInfo info;
     if (getContactFromNumber (strContact, info)) {
         foreach (PhoneInfo phone, info.arrPhones) {
-            GVAccess::simplify_number (phone.strNumber, false);
+            GVApi::simplify_number (phone.strNumber, false);
             arrNums += phone.strNumber.replace("'", "''");
         }
     }
@@ -974,7 +974,7 @@ CacheDatabase::getTextsByContact(const QString &strContact)
         info.strId = query.value(0).toString ();
         if (getContactFromLink (info)) {
             foreach (PhoneInfo phone, info.arrPhones) {
-                GVAccess::simplify_number (phone.strNumber, false);
+                GVApi::simplify_number (phone.strNumber, false);
                 arrNums += phone.strNumber.replace("'", "''");
             }
         }
@@ -1008,7 +1008,7 @@ CacheDatabase::getTextsByContact(const QString &strContact)
         }
 
         QString strNum = query.value(2).toString();
-        GVAccess::simplify_number (strNum, false);
+        GVApi::simplify_number (strNum, false);
         ContactInfo info;
         getContactFromNumber (strNum, info);
 
@@ -1083,6 +1083,9 @@ CacheDatabase::getProxySettings (bool &bEnable,
             pass = settings->value (GV_P_PASS).toString ();
         }
 
+        // Everything after this is proxy related. So if the proxy flags are
+        // not present there's no point doing the rest of the code. If there
+        // are other settings, this method will need to change.
         bEnable = bUseSystemProxy = bRequiresAuth = false;
         if (!settings->contains (GV_P_FLAGS)) {
             qWarning ("Failed to pull the proxy flags from the DB");
@@ -1326,9 +1329,8 @@ CacheDatabase::getTempFile(const QString &strLink, QString &strPath)
 }//CacheDatabase::getTempFile
 
 bool
-CacheDatabase::saveCookies(CookieJar *jar)
+CacheDatabase::saveCookies(QList<QNetworkCookie> cookies)
 {
-    QList<QNetworkCookie> cookies = jar->getAllCookies ();
     QSqlQuery query(dbMain);
     query.setForwardOnly (true);
 
@@ -1374,19 +1376,22 @@ CacheDatabase::saveCookies(CookieJar *jar)
         query.bindValue (":name", name);
         query.bindValue (":value", value);
         rv = query.exec ();
-        Q_ASSERT(rv);
+        if (!rv) {
+            qWarning() << "Failed to insert cookie into DB" << query.lastError();
+            Q_ASSERT(rv);
+        }
     }
 
     return (true);
 }//CacheDatabase::saveCookies
 
 bool
-CacheDatabase::loadCookies(CookieJar *jar)
+CacheDatabase::loadCookies(QList<QNetworkCookie> &cookies)
 {
     QSqlQuery query(dbMain);
     query.setForwardOnly (true);
 
-    QList<QNetworkCookie> cookies;
+    cookies.clear ();
     QString domain, path;
     bool isHttpOnly, isSecure, isSession;
     QByteArray name, value;
@@ -1425,6 +1430,5 @@ CacheDatabase::loadCookies(CookieJar *jar)
         cookies.append (cookie);
     }
 
-    jar->setNewCookies (cookies);
     return (true);
 }//CacheDatabase::saveCookies
