@@ -74,6 +74,9 @@ private slots:
     void messageReceived (const QString &message);
     void onSigHide ();
 
+    //! The GV Api will update us on the current progress of the NW api
+    void onSigGvApiProgress(double percent);
+
     //! Invoked when the QML says that the username and/or password has changed.
     void onUserTextChanged (const QString &strUsername);
     void onPassTextChanged (const QString &strPassword);
@@ -81,12 +84,12 @@ private slots:
     void on_action_Login_triggered();
     //! Invoked when the user clicks the login button on QML.
     void doLogin ();
-    //! Called when the web component completes login - with success or failure
+    //! Called when the GV Api completes login - with success or failure
     void loginCompleted (AsyncTaskToken *token);
 
     //! Called when the logout button is clicked
     void doLogout ();
-    //! Called when the web component completes logoff - with success or failure
+    //! Called when the GV Api completes logoff - with success or failure
     void logoutCompleted (AsyncTaskToken *token);
     //! Invoked when the system ray is clicked
     void systray_activated (QSystemTrayIcon::ActivationReason reason);
@@ -105,8 +108,6 @@ private slots:
 
     //! Invoked by the context when either observers or the user says.
     void onSigDialComplete (DialContext *ctx, bool ok);
-    //! Invoked when dialing has started
-    void dialInProgress (const QString &strNumber);
     //! Invoked when a number dial is completed.
     void dialComplete (AsyncTaskToken *token);
 
@@ -228,7 +229,6 @@ private:
     void setPassword(const QString &strPassword);
 
     //! Invoked to perform a dial
-    void dialAccessNumber (AsyncTaskToken *token);
     void fallbackDialout (DialContext *ctx);
 
     void clearSmsDestinations();
