@@ -33,17 +33,7 @@ Contact: yuvraaj@gmail.com
 
 #include "NwReqTracker.h"
 
-#ifdef QT_NO_DEBUG
-#define NO_DBGINFO      1
-#else
-#define NO_DBGINFO      0
-#endif
-
-// Uncomment these to disable webview even in debug
-// #undef NO_DBGINFO
-// #define NO_DBGINFO 1
-
-#define SKYPE_CLIENT_NAME "qgvdial"
+#define APPLICATION_NAME "qgvdial"
 
 #define UA_N900   "Mozilla/5.0 (X11; U; Linux armv7l; en-GB; rv:1.9.2a1pre) Gecko/20090928 Firefox/3.5 Maemo Browser 1.4.1.21 RX-51 N900"
 #define UA_IPHONE  "Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16"
@@ -66,6 +56,7 @@ Contact: yuvraaj@gmail.com
 
 #define Q_DEBUG(_s) qDebug() << QString("%1(%2): %3").arg(__FUNCTION__).arg(__LINE__).arg(_s)
 #define Q_WARN(_s) qWarning() << QString("%1(%2): %3").arg(__FUNCTION__).arg(__LINE__).arg(_s)
+#define Q_CRIT(_s) qCritical() << QString("%1(%2): %3").arg(__FUNCTION__).arg(__LINE__).arg(_s)
 
 struct GVRegisteredNumber
 {
